@@ -21,7 +21,6 @@
 #include <QFile>
 #include <QDir>
 #include <QUrl>
-#include <QDateTime>
 #include <QCoreApplication>
 #include <QTimer>
 #include <QStandardPaths>
@@ -40,6 +39,7 @@ namespace Arqiver {
 
 static const QRegularExpression newlineExp("(?<!\\\\)\\\\n");
 static const QRegularExpression tabExp("(?<!\\\\)\\\\t");
+static const QRegularExpression startBslashExp("(^|/)\\\\"); // used with startBackslash_
 
 Backend::Backend(QObject *parent) : QObject(parent) {
   tarCmnd_ = TAR_CMD;
@@ -48,10 +48,40 @@ Backend::Backend(QObject *parent) : QObject(parent) {
   connect(&proc_, &QProcess::readyReadStandardOutput, this, &Backend::processData);
   connect(&proc_, &QProcess::started, this, &Backend::processStarting);
   connect(&proc_, &QProcess::errorOccurred, this, &Backend::onError);
+
   isKilled_ = false;
-  LIST = false;
+  listing_ = false;
   isGzip_ = is7z_ = false;
   starting7z_ = encryptionQueried_ = encrypted_ = encryptedList_ = false;
+  startBackslash_ = false; // used only with bsdtar in "Backend::startExtract()"
+
+  watcher_ = new QFileSystemWatcher(this);
+  connect(watcher_, &QFileSystemWatcher::fileChanged, [this](const QString& path) {
+    /* WARNING: If the parent directory of an extracted file contains unextracted file(s),
+                bsdtar resets the modification time of the file on extracting the parent
+                directory with the "-k" option, and so, the watcher emits "fileChanged()".
+                As a workaround, we keep track of modification times. */
+    if (QFile::exists(path)) {
+      bool emitSignal(isGzip_ || is7z_ || !modTimes_.contains(path));
+      if (!emitSignal) {
+        QDateTime modTime = QFileInfo(path).lastModified();
+        if (modTimes_.value(path) < modTime) {
+          emitSignal = true;
+          modTimes_.insert(path, modTime);
+        }
+      }
+      if (emitSignal) {
+        emit fileModified(true);
+        if (!changedFiles_.contains(path))
+          changedFiles_ << path;
+      }
+      if (!watcher_->files().contains(path)){
+        watcher_->addPath(path); // recommended by Qt doc
+      }
+    }
+    else
+      modTimes_.remove(path);
+  });
 }
 
 Backend::~Backend() {
@@ -92,11 +122,16 @@ QString Backend::getMimeType(const QString &fname) {
 }
 
 void Backend::loadFile(const QString& path, bool withPassword) {
-  /* check if the file extraction directory can be made
+  /* check if the file extraction directory can be made,
      but don't create it until a file is viewed */
   const QString curTime = QDateTime::currentDateTime().toString("yyyyMMddhhmmsszzz");
-  if (!arqiverDir_.isEmpty())
+  if (!arqiverDir_.isEmpty()) {
+    watcher_->removePaths(watcher_->files());
+    changedFiles_.clear();
+    modTimes_.clear();
+    emit fileModified(false);
     QDir(arqiverDir_).removeRecursively();
+  }
   QString cache = QStandardPaths::writableLocation(QStandardPaths::TempLocation);
   if (!cache.isEmpty()) {
     QDir cacheDir(cache);
@@ -107,11 +142,8 @@ void Backend::loadFile(const QString& path, bool withPassword) {
 
   /*
      NOTE: So far, bsdtar, gzip and 7z are supported.
-           Also, password protected 7z archives can be
-           extracted and created.
-
-           7z has two kinds of prompts that we avoid:
-           password and overwrite prompts.
+           Also, password protected 7z archives can be extracted and created.
+           7z has two kinds of prompts that we avoid: password and overwrite prompts.
   */
 
   filepath_ = path;
@@ -128,18 +160,18 @@ void Backend::loadFile(const QString& path, bool withPassword) {
     isGzip_ = true; is7z_ = false;
   }
   else if (mt == "application/x-7z-compressed"
-           || mt == "application/x-ms-dos-executable" || mt == "application/x-msi"
+           || mt == "application/x-ms-dos-executable" || mt == "application/vnd.microsoft.portable-executable" || mt == "application/x-msdownload" || mt == "application/x-msi"
            || mt == "application/vnd.ms-cab-compressed" || mt == "application/vnd.rar"
-           || mt == "application/x-cd-image" || mt == "application/vnd.appimage"
+           || mt == "application/x-cd-image" || mt == "application/vnd.efi.iso" || mt == "application/vnd.appimage"
            || mt == "application/x-xz"
            || mt == "application/zstd"
            || mt == "application/x-ace"
-           || mt == "application/x-bzip" || mt == "application/x-bzpdf" || mt == "application/x-xzpdf"
+           || mt == "application/x-bzip" || mt == "application/x-bzip1" || mt == "application/x-bzip2" || mt == "application/x-bzpdf" || mt == "application/x-xzpdf"
            || mt == "application/x-apple-diskimage") {
     is7z_ = true; isGzip_ = false;
   }
-  else if (mt == "application/x-raw-disk-image") {
-    /* 7z can't open compressed disk images and bsdtar can't handle uncompressed ones */
+  else if (mt == "application/x-raw-disk-image" || mt == "application/vnd.efi.img") {
+    /* 7z can't open compressed disk images, and bsdtar can't handle uncompressed ones */
     QMimeDatabase mimeDatabase;
     QString realMt = mimeDatabase.mimeTypeForFile(QFileInfo(path), QMimeDatabase::MatchContent).name();
     if (realMt == "application/gzip" || realMt == "application/x-cpio" || realMt == "application/x-xz") {
@@ -167,20 +199,28 @@ void Backend::loadFile(const QString& path, bool withPassword) {
     if (is7z_)
       encryptionQueried_ = true; // an empty archive doesn't have encryption (yet)
     contents_.clear();
+    startBackslash_ = false;
     emit loadingFinished();
     emit loadingSuccessful();
     emit processFinished(true, QString());
   }
 }
 
-bool Backend::canModify() const {
+bool Backend::canModify(bool *canUpdate) const {
   static QStringList validMimeTypes;
   if (validMimeTypes.isEmpty()) {
-    validMimeTypes << "application/zip" << "application/x-compressed-tar" << "application/x-gzpdf" << "image/svg+xml-compressed" << "application/x-xz-compressed-tar" << "application/x-bzip-compressed-tar" << "application/x-tar" << "application/x-lzma-compressed-tar" << "application/x-zstd-compressed-tar" << "application/x-cpio" << /*".pax" <<*/ "application/x-archive" << /*".shar" <<*/ "application/gzip" << "application/x-7z-compressed";
+    validMimeTypes << "application/zip" << "application/x-compressed-tar" << "application/x-gzpdf" << "image/svg+xml-compressed" << "application/x-xz-compressed-tar" << "application/x-bzip-compressed-tar" << "application/x-bzip1-compressed-tar" << "application/x-bzip2-compressed-tar" << "application/x-tar" << "application/x-lzma-compressed-tar" << "application/x-zstd-compressed-tar" << "application/x-cpio" << /*".pax" <<*/ "application/x-archive" << /*".shar" <<*/ "application/gzip" << "application/x-7z-compressed";
+  }
+  static QStringList updatedMimeTypes;
+  if (updatedMimeTypes.isEmpty()) {
+    updatedMimeTypes << "application/zstd" << "application/x-bzip" << "application/x-bzip1" << "application/x-bzip2" << "application/x-xz" << "application/vnd.debian.binary-package" << "application/x-rpm" << "application/x-source-rpm";
   }
   QMimeDatabase mimeDatabase;
   QString mimeTypeName = mimeDatabase.mimeTypeForFile(QFileInfo(filepath_)).name();
-  return validMimeTypes.contains(mimeTypeName);
+  bool res = archiveSingleRoot_ != "."  // not like some rpm archives
+             && validMimeTypes.contains(mimeTypeName);
+  *canUpdate = (archiveSingleRoot_ != "." && (res || updatedMimeTypes.contains(mimeTypeName)));
+  return res;
 }
 
 QString Backend::currentFile() const {
@@ -245,14 +285,102 @@ static inline void skipExistingFiles(QString& file) {
   file += suffix;
 }
 
-static inline QString escapedWildCard(const QString& str)
+// This is only for bsdtar, which uses an ed-like pattern substitution.
+// WARNING: Here it is supposed that backslashes are escaped by bsdtar.
+static inline QString escapeSpecialChars(const QString& str)
 {
   QString newStr = str;
-  newStr.replace("*", "\\*").replace("[", "\\[");
+  newStr.replace("*", "\\*").replace("[", "\\[").replace("^", "\\^")
+        .replace("$", "\\$").replace("?", "\\?");
   return newStr;
 }
 
-void Backend::startAdd(const QStringList& paths,  bool absolutePaths) {
+void Backend::updateArchive() {
+  if (arqiverDir_.isEmpty() || changedFiles_.isEmpty()
+      || !QFile::exists(filepath_)) {
+    return;
+  }
+  QDir dir(arqiverDir_);
+  if (!dir.exists()) return;
+
+  emit fileModified(false);
+  keyArgs_.clear();
+  QStringList args;
+
+  if (is7z_) {
+    // only add the top files/folders of the temporary directory; 7z takes care of the rest
+    QStringList paths;
+    const QStringList entries = dir.entryList(QDir::NoDotAndDotDot | QDir::Dirs | QDir::Files);
+    if (entries.isEmpty()) return;
+    for (const QString &str : entries)
+      paths << arqiverDir_ + "/" + str;
+    if (encryptedList_) {
+      if (pswrd_.isEmpty())
+        return;
+      args << "-mhe=on" << "-p" + pswrd_;
+    }
+    else if (!pswrd_.isEmpty()) {
+      args << "-p" + pswrd_;
+      encrypted_ = true;
+    }
+    args << "a" << fileArgs_ << paths;
+    starting7z_ = true;
+    keyArgs_ << "a";
+    proc_.start ("7z", args);
+    return;
+  }
+
+  emit processStarting();
+
+  if (isGzip_) {
+    args << "--to-stdout" << "--force" << changedFiles_.at(0);
+    tmpProc_.setStandardOutputFile(filepath_);
+    tmpProc_.start("gzip", args);
+    if (tmpProc_.waitForStarted()) {
+      while (!tmpProc_.waitForFinished(500))
+        QCoreApplication::processEvents();
+    }
+    emit processFinished(tmpProc_.exitCode() == 0, QString());
+    return;
+  }
+
+  // first remove the files from the archive, waiting until the process is finished...
+  args << "-c" << "-a";
+  skipExistingFiles(tmpfilepath_); // practically not required
+  args << "-f" << tmpfilepath_;
+#if (QT_VERSION >= QT_VERSION_CHECK(6,6,0))
+  for (const QString &str : std::as_const(changedFiles_))
+#else
+  for (const QString &str : qAsConst(changedFiles_))
+#endif
+  {
+    /* WARNING: Since the workaround for bsdtar's escaped backslashes is already applied,
+                they need to be escaped again, before other special characters are escaped. */
+    args << "--exclude" << "^" + escapeSpecialChars(str.section('/', 3).replace("\\", "\\\\"));
+  }
+  args << "@" + filepath_;
+  tmpProc_.start(tarCmnd_, args);
+  if (tmpProc_.waitForStarted()) {
+    while (!tmpProc_.waitForFinished(500))
+      QCoreApplication::processEvents();
+  }
+  if (QFile::exists(tmpfilepath_)) {
+    if (tmpProc_.exitCode() == 0) {
+      QFile::remove(filepath_);
+      QFile::rename(tmpfilepath_, filepath_);
+    }
+    else
+      QFile::remove(tmpfilepath_);
+  }
+  emit processFinished(tmpProc_.exitCode() == 0, QString());
+  if (tmpProc_.exitCode() != 0)
+    return;
+
+  // ... then add the modified files to the archive with a proper parent path
+  startAdd(changedFiles_, arqiverDir_);
+}
+
+void Backend::startAdd(const QStringList& paths, const QString& parentPath, bool absolutePaths) {
   keyArgs_.clear();
   QStringList filePaths = paths;
   /* exclude the archive itself */
@@ -308,13 +436,16 @@ void Backend::startAdd(const QStringList& paths,  bool absolutePaths) {
     return;
   }
   /* NOTE: All paths should have the same parent directory.
-           Check that and put the wrong paths into insertQueue_. */
-  QString parent = filePaths.at(0).section("/", 0, -2);
+           Check that, and put the wrong paths into insertQueue_.
+           (For now, "parentPath" is used only in "updateArchive".) */
+  const QString parent = parentPath.isEmpty() ? filePaths.at(0).section("/", 0, -2) : parentPath;
   insertQueue_.clear();
-  for (int i = 1; i < filePaths.length(); i++) {
-    if (filePaths.at(i).section("/", 0, -2) != parent) {
-      insertQueue_ << filePaths.takeAt(i);
-      i--;
+  if (parentPath.isEmpty()) {
+    for (int i = 1; i < filePaths.length(); i++) {
+      if (filePaths.at(i).section("/", 0, -2) != parent) {
+        insertQueue_ << filePaths.takeAt(i);
+        i--;
+      }
     }
   }
   args << "-c" << "-a";
@@ -344,6 +475,8 @@ void Backend::startAdd(const QStringList& paths,  bool absolutePaths) {
 }
 
 void Backend::startRemove(const QStringList& paths) {
+  if (!QFile::exists(filepath_)) return;
+
   keyArgs_.clear();
   if (isGzip_) return;
   QStringList filePaths = paths;
@@ -352,6 +485,19 @@ void Backend::startRemove(const QStringList& paths) {
   if (contents_.isEmpty() || filePaths.isEmpty() || !QFile::exists(filepath_))
     return; // invalid
   filePaths.removeDuplicates();
+
+  // a modified file may be removed
+  if (!changedFiles_.isEmpty()) {
+#if (QT_VERSION >= QT_VERSION_CHECK(6,6,0))
+    for (const QString &str : std::as_const(filePaths))
+#else
+    for (const QString &str : qAsConst(filePaths))
+#endif
+      changedFiles_.removeOne(arqiverDir_ + "/" + str);
+    if (changedFiles_.isEmpty())
+      emit fileModified(false);
+  }
+
   QStringList args;
   if (is7z_) {
     if (encrypted_)
@@ -366,7 +512,7 @@ void Backend::startRemove(const QStringList& paths) {
   skipExistingFiles(tmpfilepath_); // practically not required
   args << "-f" << tmpfilepath_;
   for (int i = 0; i < filePaths.length(); i++) {
-    args << "--exclude" << escapedWildCard(filePaths.at(i));
+    args << "--exclude" << "^" + escapeSpecialChars(filePaths.at(i));
   }
   args << "@" + filepath_;
   keyArgs_ << "-c" << "-a" << "--exclude";
@@ -378,10 +524,12 @@ void Backend::startExtract(const QString& path, const QString& file, bool overwr
 }
 
 void Backend::startExtract(const QString& path, const QStringList& files, bool overwrite, bool preservePaths) {
+  if (!QFile::exists(filepath_)) return;
+
   keyArgs_.clear();
   if (isGzip_) {
     /* if the extraction takes place in the same directory, we could do it
-       in the usual way but the standard output method works in all cases */
+       in the usual way, but the standard output method works in all cases */
     /*if (0 && path == filepath_.section("/", 0, -2)) {
       proc_.start("gzip", QStringList() << "-d" << "-k" << filepath_);
       return;
@@ -418,8 +566,10 @@ void Backend::startExtract(const QString& path, const QStringList& files, bool o
     filesList.replaceInStrings(newlineExp, "\n").replaceInStrings(tabExp, "\t");
   }
 
+  bool noFileList(filesList.isEmpty());
+
   if (is7z_) {
-    if (filesList.isEmpty())
+    if (noFileList)
       args << "-aou"; // auto-rename: the archive may contain files with identical names
     else if (overwrite)
       args << "-aoa"; // overwrite without prompt
@@ -436,15 +586,19 @@ void Backend::startExtract(const QString& path, const QStringList& files, bool o
     if (!overwrite)
       args << "-k";
     args << fileArgs_;
-    if (!filesList.isEmpty()) {
+    if (!noFileList) {
         /* If a file comes after its containing folder in the command line,
            bsdtar doesn't extract the folder. So, we sort the list and read it inversely. */
         filesList.sort();
         int N = filesList.length();
         for (int i = 0; i < N; i++) {
-          if (filesList[N - 1 - i].simplified().isEmpty())
+          if (filesList[N - 1 - i].simplified().isEmpty()
+              // see the end of this function for the reason
+              || (startBackslash_ && filesList[N - 1 - i].contains(startBslashExp))) {
+            filesList.removeAt(N - 1 - i);
             continue;
-          args << "--include" << escapedWildCard(filesList[N - 1 - i])
+          }
+          args << "--include" << escapeSpecialChars(filesList[N - 1 - i])
                << "--strip-components" << QString::number(filesList[N - 1 - i].count("/"));
         }
     }
@@ -452,18 +606,22 @@ void Backend::startExtract(const QString& path, const QStringList& files, bool o
   }
 
   QString xPath = path;
-  bool archiveRootExists(false);
+  bool archiveRootChanged(false);
 
-  /* prevent overwriting by making an appropriate directory and extracting into it
-     if the whole archive is going to be extracted (otherwise, overwriting will be handled by mainWin) */
-  if (filesList.isEmpty()) {
+  /* Prevent overwriting by making an appropriate directory and extracting into it
+     if the whole archive is going to be extracted (otherwise, overwriting should be handled by GUI) */
+  if (noFileList) {
     QString archiveSingleRoot = archiveSingleRoot_;
-    if (!archiveSingleRoot.isEmpty() && archiveSingleRoot.startsWith("."))
-      archiveSingleRoot.remove(0, 1); // no hidden extraction folder
+    if (!archiveSingleRoot.isEmpty() && archiveSingleRoot.startsWith(".")) {
+      archiveSingleRoot.remove(0, 1); // no hidden extraction folder or single hidden extracted file
+      archiveRootChanged = true;
+    }
     if (!archiveSingleRoot.isEmpty()) { // is empty with some rpm archives or when an encrypted list isn't known yet
       archiveSingleRoot.replace(newlineExp, "\n").replace(tabExp, "\t");
+      if (!isGzip_ && !is7z_)
+        archiveSingleRoot.replace("\\\\", "\\"); // WARNING: bsdtar escapes backslashes.
       if (QFile::exists(xPath + "/" + archiveSingleRoot)) {
-        archiveRootExists = true;
+        archiveRootChanged = true;
         QDir dir (xPath);
         QString subdirName = archiveSingleRoot;
         xPath += "/" + subdirName;
@@ -479,8 +637,14 @@ void Backend::startExtract(const QString& path, const QStringList& files, bool o
 
         dir.mkdir(subdirName);
       }
+      else if (archiveRootChanged) {
+        QDir dir (xPath);
+        xPath += "/" + archiveSingleRoot;
+        dir.mkdir(archiveSingleRoot);
+      }
     }
     else { // the archive doesn't have a parent dir and isn't a single file
+      archiveRootChanged = false;
       QDir dir(xPath);
       QString subdirName = filepath_.section("/", -1);
       if (subdirName.contains(".")) {
@@ -507,13 +671,17 @@ void Backend::startExtract(const QString& path, const QStringList& files, bool o
 
   if (is7z_) {
     args << "-o" + xPath;
-    if (!filesList.isEmpty())
+    if (!noFileList)
       args << filesList;
     proc_.start("7z", args);
   }
   else {
+    if (!noFileList && filesList.isEmpty())
+      return; // it was emptied above
     args << "-C" << xPath;
-    if (archiveRootExists && contents_.size() > 1)
+    /* WARNING: Because of a nasty bug in bsdtar, "--strip-components" removes
+                the start backslash, and so, it can result in a mess. */
+    if (!startBackslash_ && archiveRootChanged && contents_.size() > 1)
       args << "--strip-components" << "1"; // the parent name is changed
     keyArgs_ << "-C";
     proc_.start(tarCmnd_, args); // doesn't create xPath if not existing
@@ -525,6 +693,7 @@ bool Backend::isEncryptedPath(const QString& path) const {
   return (encryptedList_ || encryptedPaths_.contains(path));
 }
 
+// Used only with encrypted archives
 bool Backend::isSingleExtracted(const QString& archivePath) const {
   if (arqiverDir_.isEmpty()) return false;
   QString str = archivePath;
@@ -543,6 +712,8 @@ bool Backend::allChildrenExyracted(const QString& parent) const {
         QString str = file;
         if (str.startsWith("./")) // as with some rpm archives
           str.remove(0, 2);
+        if (!isGzip_ && !is7z_)
+          str.replace("\\\\", "\\"); // WARNING: bsdtar escapes backslashes.
         if (!QFile::exists(arqiverDir_ + "/" + str))
           return false;
       }
@@ -586,6 +757,11 @@ void Backend::removeSingleExtracted(const QString& archivePath) const {
 
 // Returns false only when a password is needed but it's nonempty and wrong.
 bool Backend::startViewFile(const QString& path) {
+  if (!QFile::exists(filepath_))
+    return true; // "false" is reserved for password of 7z
+
+  bool res = true;
+
   /* the path may contain newlines, which have been escaped and are restored here */
   QString realPath(path);
   realPath.replace(newlineExp, "\n").replace(tabExp, "\t");
@@ -603,9 +779,13 @@ bool Backend::startViewFile(const QString& path) {
   QString fileName = (arqiverDir_.isEmpty() ? QDateTime::currentDateTime().toString("yyyyMMddhhmmsszzz")
                                             : parentDir + "/")
                      + realPath.section("/",-1);
+  if (!isGzip_ && !is7z_)
+    fileName.replace("\\\\", "\\"); // WARNING: bsdtar escapes backslashes.
   QFile file(fileName);
   bool fileExists(file.exists());
   if (fileExists && file.size() == static_cast<qint64>(0)) {
+    watcher_->removePath(fileName);
+    modTimes_.remove(fileName);
     file.remove();
     fileExists = false;
   }
@@ -625,57 +805,78 @@ bool Backend::startViewFile(const QString& path) {
         while (!tmpProc_.waitForFinished(500))
           QCoreApplication::processEvents();
       }
-      bool res(tmpProc_.exitCode() == 0 || pswrd_.isEmpty());
+      res = tmpProc_.exitCode() == 0 || pswrd_.isEmpty();
       if (!res)
         pswrd_ = QString(); // avoid overwrite prompt if there are more than one password
       emit processFinished(tmpProc_.exitCode() == 0, QString());
-      if (tmpProc_.exitCode() == 0) {
-        if (!QFileInfo::exists(fileName)) { // handle links
-          errorMsg(tr("This file is a link but its target does not exist."));
-        }
-        else if (!QProcess::startDetached("gio", QStringList() << "open" << fileName)) // "gio" is more reliable
-          QDesktopServices::openUrl(QUrl::fromLocalFile(fileName));
+      if (tmpProc_.exitCode() != 0)
+        return res;
+    }
+    else {
+      QString cmnd;
+      if (isGzip_) {
+        cmnd = "gzip";
+        args << "-d" << "--to-stdout" << filepath_;
+        emit processStarting();
+        tmpProc_.setStandardOutputFile(fileName);
       }
-      return res;
+      else { // bsdtar
+        cmnd = tarCmnd_;
+        // "--fast-read" interferes with extraction of directories
+        if (isDir(path))
+          args << "-x" << "--no-same-owner";
+        else
+          args << "-x" << "--no-same-owner" << "--fast-read";
+        args << "-k" << fileArgs_
+             << "--include" << escapeSpecialChars(realPath) << "-C" << arqiverDir_;
+        /* NOTE: The following arguments were also possible with "fileName" as the standard output
+                 (as with Gzip) but symlinks couldn't be handled in that way. */
+        //args << "-x" << fileArgs_ << "--include" << escapeSpecialChars(realPath) << "--to-stdout";
+        emit processStarting();
+        tmpProc_.setStandardOutputFile(QProcess::nullDevice());
+      }
+      tmpProc_.start(cmnd, args);
+      if (tmpProc_.waitForStarted()) {
+        while (!tmpProc_.waitForFinished(500))
+          QCoreApplication::processEvents();
+      }
+      emit processFinished(tmpProc_.exitCode() == 0, QString());
+      if (tmpProc_.exitCode() != 0)
+        return true;
     }
-    QString cmnd;
-    if (isGzip_) {
-      cmnd = "gzip";
-      args << "-d" << "--to-stdout" << filepath_;
-      emit processStarting();
-      tmpProc_.setStandardOutputFile(fileName);
-    }
-    else { // bsdtar
-      cmnd = tarCmnd_;
-      args << "-x" << "--no-same-owner" << "-k" << fileArgs_
-           << "--include" << escapedWildCard(realPath) << "-C" << arqiverDir_;
-      /* NOTE: The following arguments were also possible with "fileName" as the standard output
-               (as with Gzip) but symlinks couldn't be handled in that way. */
-      //args << "-x" << fileArgs_ << "--include" << escapedWildCard(realPath) << "--to-stdout";
-      emit processStarting();
-      tmpProc_.setStandardOutputFile(QProcess::nullDevice());
-    }
-    tmpProc_.start(cmnd, args);
-    if (tmpProc_.waitForStarted()) {
-      while (!tmpProc_.waitForFinished(500))
-        QCoreApplication::processEvents();
-    }
-    emit processFinished(tmpProc_.exitCode() == 0, QString());
-    if (tmpProc_.exitCode() != 0)
-      return true;
-    if (!QFileInfo::exists(fileName)) { // handle links
+    // handle links
+    if (!QFileInfo::exists(fileName)) {
       errorMsg(tr("This file is a link but its target does not exist."));
-      return true;
+      return res;
     }
   }
   else
     emit processFinished(true, QString());
+
+  // Since the file may be inside a directory extracted by "extractTempFiles()",
+  // we may need to add it to the watch list also when it already exists.
+  QFileInfo info(fileName);
+  if (!info.isDir()) {
+    const QString finalTarget = info.canonicalFilePath();
+    if (finalTarget == fileName || finalTarget.startsWith(arqiverDir_ + QLatin1Char('/'))) {
+      watcher_->addPath(finalTarget);
+      if (!isGzip_ && !is7z_)
+        modTimes_.insert(finalTarget, info.lastModified());
+    }
+  }
+
   if (!QProcess::startDetached("gio", QStringList() << "open" << fileName)) // "gio" is more reliable
     QDesktopServices::openUrl(QUrl::fromLocalFile(fileName));
-  return true;
+  return res;
 }
 
 void Backend::extractTempFiles(const QStringList& paths) {
+  if (!QFile::exists(filepath_)) {
+    emit processFinished(true, QString());
+    emit tempFilesExtracted(QStringList()); // needed with drag-and-drop
+    return;
+  }
+
   QStringList realPaths(paths);
   realPaths.removeAll(QString());
   if (!realPaths.isEmpty()) {
@@ -713,6 +914,8 @@ void Backend::extractTempFiles(const QStringList& paths) {
       }
       else
         parentDir = arqiverDir_; // top-level
+      if (!isGzip_ && !is7z_)
+        realPath.replace("\\\\", "\\"); // WARNING: bsdtar escapes backslashes.
       QString fileName = parentDir + "/" + realPath.section("/",-1);
       tempFileNames << fileName;
       /* check whether it's already extracted (FIXME: this doesn't cover all symlinks) */
@@ -726,7 +929,7 @@ void Backend::extractTempFiles(const QStringList& paths) {
 
   if (!realPaths.isEmpty()) {
     QStringList args;
-    /* Gzip */
+
     if (isGzip_) {
       if (tempFileNames.size() == 1) {
         args << "-d" << "--to-stdout" << filepath_;
@@ -739,11 +942,13 @@ void Backend::extractTempFiles(const QStringList& paths) {
         }
         emit processFinished(tmpProc_.exitCode() == 0, QString());
         emit tempFilesExtracted(tempFileNames);
+
+        if (tmpProc_.exitCode() == 0)
+          watcher_->addPath(tempFileNames.at(0));
       }
       return;
     }
 
-    /* 7z */
     if (is7z_) {
       args << "-aos"; // skip extraction of existing files
       if (encrypted_ )
@@ -758,43 +963,72 @@ void Backend::extractTempFiles(const QStringList& paths) {
       }
       if (tmpProc_.exitCode() != 0)
         pswrd_ = QString();
-      emit processFinished(tmpProc_.exitCode() == 0, QString());
-      emit tempFilesExtracted(tempFileNames);
-      return;
+    }
+    else {
+      /* bsdtar */
+      bool noDir = true;
+      for (const QString &str : paths) {
+        if (isDir(str)) {
+          noDir = false;
+          break;
+        }
+      }
+      // "--fast-read" interferes with extraction of directories
+      if (noDir)
+        args << "-x" << "--no-same-owner" << "--fast-read" << "-k" << fileArgs_;
+      else
+        args << "-x" << "--no-same-owner" << "-k" << fileArgs_;
+
+      /* If a file comes after its containing folder in the command line,
+         bsdtar doesn't extract the folder. So, we sort the list and read it inversely. */
+      realPaths.sort();
+      int N = realPaths.length();
+      for (int i = 0; i < N; i++)
+        args << "--include" << escapeSpecialChars(realPaths[N - 1 - i]);
+
+      args << "-C" << arqiverDir_;
+      emit processStarting();
+      tmpProc_.setStandardOutputFile(QProcess::nullDevice());
+      tmpProc_.start(tarCmnd_, args);
+      if (tmpProc_.waitForStarted()) {
+        while (!tmpProc_.waitForFinished(500))
+          QCoreApplication::processEvents();
+      }
     }
 
-    /* bsdtar */
-    args << "-x" << "--no-same-owner" << "-k" << fileArgs_;
-
-    /* If a file comes after its containing folder in the command line,
-       bsdtar doesn't extract the folder. So, we sort the list and read it inversely. */
-    realPaths.sort();
-    int N = realPaths.length();
-    for (int i = 0; i < N; i++)
-      args << "--include" << escapedWildCard(realPaths[N - 1 - i]);
-
-    args << "-C" << arqiverDir_;
-    emit processStarting();
-    tmpProc_.setStandardOutputFile(QProcess::nullDevice());
-    tmpProc_.start(tarCmnd_, args);
-    if (tmpProc_.waitForStarted()) {
-      while (!tmpProc_.waitForFinished(500))
-        QCoreApplication::processEvents();
-    }
     emit processFinished(tmpProc_.exitCode() == 0, QString());
     emit tempFilesExtracted(tempFileNames);
+    if (tmpProc_.exitCode() != 0) return;
   }
   else { // all paths are already extracted
     emit processFinished(true, QString());
     emit tempFilesExtracted(tempFileNames);
   }
+
+  // files may be edited also by drag-and-drop
+#if (QT_VERSION >= QT_VERSION_CHECK(6,6,0))
+  for (const QString &str : std::as_const(tempFileNames))
+#else
+  for (const QString &str : qAsConst(tempFileNames))
+#endif
+  {
+    QFileInfo info(str);
+    if (!info.isDir()) {
+      const QString finalTarget = info.canonicalFilePath();
+      if (finalTarget == str || finalTarget.startsWith(arqiverDir_ + QLatin1Char('/'))) {
+        watcher_->addPath(finalTarget);
+        if (!is7z_)
+          modTimes_.insert(finalTarget, info.lastModified());
+      }
+    }
+  }
 }
 
 void Backend::parseLines(QStringList& lines) {
   static bool hasSingleRoot = false;
   if (contents_.isEmpty()) {
     hasSingleRoot = true;
-    archiveSingleRoot_ = QString(); // if existent, may mean a parent dir or single file
+    archiveSingleRoot_ = QString(); // if existing, may mean a parent dir or single file
   }
   if (is7z_) {
     static int attrIndex = 0;
@@ -814,13 +1048,9 @@ void Backend::parseLines(QStringList& lines) {
     for (int i = 0; i < lines.length(); i++) {
       if (lines.at(i).simplified().isEmpty() || lines.at(i).startsWith("----") || lines.at(i).startsWith(" = "))
         continue;
-      if (LIST) {
+      if (listing_) {
         QString file;
-#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
         QStringList info = lines.at(i).split(" ",Qt::SkipEmptyParts);
-#else
-        QStringList info = lines.at(i).split(" ",QString::SkipEmptyParts);
-#endif
         if (info.size() < 2) continue; // invalid line
         // Format: [Date, Time, Attr, Size, Compressed, Name]
         if (info.size() >= 6 && info.at(2) == "Attr") { // header
@@ -851,11 +1081,7 @@ void Backend::parseLines(QStringList& lines) {
                 && lines.at(i+1).startsWith("---") // next line is end of table
                 && attrIndex + 5 < lines.at(i+2).size()
                 && lines.at(i+2).left(attrIndex + 6).simplified().isEmpty()) { // no Attr and nothing before it
-#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
               QStringList infoNext = lines.at(i+2).split(" ",Qt::SkipEmptyParts);
-#else
-              QStringList infoNext = lines.at(i+2).split(" ",QString::SkipEmptyParts);
-#endif
               // Format of infoNext: [Size(?), Compressed, Number(=1), "files"]
               if (!infoNext.isEmpty()) {
                 if (cSizeIndex < lines.at(i+2).size() && !lines.at(i+2).at(cSizeIndex - 1).isSpace()) {
@@ -910,11 +1136,7 @@ void Backend::parseLines(QStringList& lines) {
   for (int i = 0; i < lines.length(); i++) {
     if (isGzip_) {
       // lines[i] is:                 <compressed_size>                   <uncompressed_size> -33.3% /x/y/z}
-#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
       QStringList info = lines.at(i).split(" ",Qt::SkipEmptyParts);
-#else
-      QStringList info = lines.at(i).split(" ",QString::SkipEmptyParts);
-#endif
       if (contents_.isEmpty() && info.size() >= 4) {
         int indx = lines.at(i).indexOf("% ");
         if (indx > -1) {
@@ -945,6 +1167,8 @@ void Backend::parseLines(QStringList& lines) {
           file.chop(1);
         }
         if (file.isEmpty()) continue; // impossible
+        if (file.contains(startBslashExp))
+          startBackslash_ = true;
         if (hasSingleRoot) {
           if (archiveSingleRoot_.isEmpty()) {
             archiveSingleRoot_ = file.section('/', 0, 0);
@@ -966,11 +1190,7 @@ void Backend::parseLines(QStringList& lines) {
     if (indx != 0 || match.capturedLength() == lines.at(i).length())
       continue; // invalid line
     QStringList info;
-#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
     info << lines.at(i).left(match.capturedLength()).split(" ",Qt::SkipEmptyParts);
-#else
-    info << lines.at(i).left(match.capturedLength()).split(" ",QString::SkipEmptyParts); // 8 elements
-#endif
     info << lines.at(i).right(lines.at(i).length() - match.capturedLength());
     // here, info is like ("-rw-r--r--", "1", "0", "0", "645", "Feb", "5", "2016", "x/y -> /a/b")
     QString file = info.at(8);
@@ -991,6 +1211,8 @@ void Backend::parseLines(QStringList& lines) {
       if (info.at(0).startsWith("-"))
         info[0].replace(0, 1, "l");
     }
+    if (file.contains(startBslashExp))
+      startBackslash_ = true;
     if (hasSingleRoot) {
       if (archiveSingleRoot_.isEmpty()) {
           archiveSingleRoot_ = file.section('/', 0, 0);
@@ -1008,8 +1230,9 @@ void Backend::parseLines(QStringList& lines) {
 
 void Backend::startList(bool withPassword) {
   contents_.clear();
+  startBackslash_ = false;
   keyArgs_.clear();
-  LIST = true;
+  listing_ = true;
   if (isGzip_) {
     keyArgs_ << "-l";
     proc_.start("gzip", QStringList() << "-l" << filepath_);
@@ -1037,11 +1260,12 @@ void Backend::procFinished(int retcode, QProcess::ExitStatus) {
     isKilled_ = false;
     if (keyArgs_.contains("l") || keyArgs_.contains("-tv") || keyArgs_.contains("-l")) { // listing
       /* reset most variables (the rest will be reset with the next loading) */
-      LIST = false;
+      listing_ = false;
       isGzip_ = is7z_ = false;
       starting7z_ = encryptionQueried_ = encrypted_ = encryptedList_ = false;
       keyArgs_.clear();
       contents_.clear();
+      startBackslash_ = false;
       insertQueue_.clear();
       encryptedPaths_.clear();
       pswrd_ = archiveSingleRoot_ = result_ = data_ = QString();
@@ -1070,13 +1294,14 @@ void Backend::procFinished(int retcode, QProcess::ExitStatus) {
 
   /* NOTE: processFinished() should be emitted once, in the end */
   processData();
-  LIST = false;
+  listing_ = false;
   if (is7z_) {
     starting7z_ = false;
     if (keyArgs_.contains("l")) { // listing
       emit loadingFinished();
       if (retcode != 0) {
         contents_.clear();
+        startBackslash_ = false;
         result_ = tr("Could not read archive");
       }
       else if (result_.isEmpty()) {
@@ -1120,6 +1345,7 @@ void Backend::procFinished(int retcode, QProcess::ExitStatus) {
   if (keyArgs_.contains("-tv") || keyArgs_.contains("-l")) { // listing
     if (retcode != 0) {
       contents_.clear();
+      startBackslash_ = false;
       result_ = tr("Could not read archive");
     }
     else if (result_.isEmpty()) {
@@ -1198,19 +1424,11 @@ void Backend::processData() {
         encryptedList_ = encrypted_ = true;
       }
       else {
-#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
         const QStringList& items = read.split("\n\n", Qt::SkipEmptyParts);
-#else
-        const QStringList& items = read.split("\n\n", QString::SkipEmptyParts);
-#endif
         for (const QString& thisItem : items) {
           if (thisItem.contains("\nEncrypted = +")) {
             /* the archive has an encrypted file but its header isn't encrypted */
-#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
             QStringList lines = thisItem.split("\n", Qt::SkipEmptyParts);
-#else
-            QStringList lines = thisItem.split("\n", QString::SkipEmptyParts);
-#endif
             if (!lines.isEmpty()) {
               QString pathLine;
               if (lines.at(0).startsWith("Path = "))
@@ -1237,11 +1455,7 @@ void Backend::processData() {
 
   /* NOTE: Because 7x doesn't escape newlines in file names, the archives
            that contain such files can't be processed correctly. */
-#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
   QStringList lines = read.split("\n", Qt::SkipEmptyParts);
-#else
-  QStringList lines = read.split("\n", QString::SkipEmptyParts);
-#endif
 
   /* Gzip doesn't escape newlines either but that can be worked around */
   if (isGzip_ && lines.size() >= 2) {
@@ -1251,7 +1465,7 @@ void Backend::processData() {
     lines << joined;
   }
 
-  if (LIST)
+  if (listing_)
     parseLines(lines);
   if (is7z_) {
     if (read.contains("\nERROR")) { // ERROR: Data Error in encrypted file. Wrong password?
