@@ -4,7 +4,7 @@
 <context>
     <name>Arqiver::AboutDialog</name>
     <message>
-        <location filename="../../about.ui" line="144"/>
+        <location filename="../../about.ui" line="148"/>
         <source>License</source>
         <translation>Licensz</translation>
     </message>
@@ -12,44 +12,43 @@
 <context>
     <name>Arqiver::Backend</name>
     <message>
-        <location filename="../../backends.cpp" line="634"/>
-        <location filename="../../backends.cpp" line="667"/>
+        <location filename="../../backends.cpp" line="849"/>
         <source>This file is a link but its target does not exist.</source>
         <translation>Ez a fájl egy link, de a célfájlja nem létezik.</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1049"/>
-        <location filename="../../backends.cpp" line="1080"/>
-        <location filename="../../backends.cpp" line="1123"/>
+        <location filename="../../backends.cpp" line="1273"/>
+        <location filename="../../backends.cpp" line="1305"/>
+        <location filename="../../backends.cpp" line="1349"/>
         <source>Could not read archive</source>
         <translation>Nem sikerült olvasni az archívumot</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1083"/>
-        <location filename="../../backends.cpp" line="1128"/>
+        <location filename="../../backends.cpp" line="1308"/>
+        <location filename="../../backends.cpp" line="1354"/>
         <source>Archive Loaded</source>
         <translation>Archívum betöltve</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1090"/>
-        <location filename="../../backends.cpp" line="1176"/>
+        <location filename="../../backends.cpp" line="1315"/>
+        <location filename="../../backends.cpp" line="1402"/>
         <source>Modification Finished</source>
         <translation>A módosítás kész</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1111"/>
-        <location filename="../../backends.cpp" line="1145"/>
+        <location filename="../../backends.cpp" line="1336"/>
+        <location filename="../../backends.cpp" line="1371"/>
         <source>Extraction Finished</source>
         <translation>A kibontás kész</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1114"/>
-        <location filename="../../backends.cpp" line="1164"/>
+        <location filename="../../backends.cpp" line="1339"/>
+        <location filename="../../backends.cpp" line="1390"/>
         <source>Extraction Failed</source>
         <translation>A kibontás sikertelen</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1273"/>
+        <location filename="../../backends.cpp" line="1487"/>
         <source>%1 is missing from your system.
 Please install it for this kind of archive!</source>
         <translation>%1 hiányzik a rendszeréből.
@@ -80,22 +79,27 @@ Az Escape billentyűvel törölheti a szöveget.</translation>
     </message>
     <message>
         <location filename="../../pref.ui" line="118"/>
+        <source>Use system icons where possible</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../pref.ui" line="125"/>
         <source>Show prompt on removing items</source>
         <translation>Kérdés megjelenítése elemek eltávolításakor</translation>
     </message>
     <message>
-        <location filename="../../pref.ui" line="125"/>
+        <location filename="../../pref.ui" line="132"/>
         <source>If this is unchecked, only the top level directories will be expanded.</source>
         <translation>Ha ez nincs bejelölve, csak a felsőszintű könyvtárak lesznek kinyitva.</translation>
     </message>
     <message>
-        <location filename="../../pref.ui" line="128"/>
+        <location filename="../../pref.ui" line="135"/>
         <source>Expand all directories when opening archives</source>
         <translation>Összes könyvtár kinyitása archívumok megnyitásakor</translation>
     </message>
     <message>
-        <location filename="../../pref.ui" line="140"/>
-        <location filename="../../pref.ui" line="153"/>
+        <location filename="../../pref.ui" line="147"/>
+        <location filename="../../pref.ui" line="160"/>
         <source>Leave empty for the default.
 
 Warning: Arqiver will not work if the
@@ -106,7 +110,7 @@ Figyelmeztetés: Az Arqiver nem fog működni,
  ha a bináris nem tartozik a libarchive-hez.</translation>
     </message>
     <message>
-        <location filename="../../pref.ui" line="146"/>
+        <location filename="../../pref.ui" line="153"/>
         <source>libarchive binary:</source>
         <translation>libarchive bináris:</translation>
     </message>
@@ -121,18 +125,17 @@ Figyelmeztetés: Az Arqiver nem fog működni,
         <translation>Ikonok mérete:</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="54"/>
+        <location filename="../../pref.cpp" line="56"/>
         <source>px</source>
         <translation>px</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="208"/>
-        <location filename="../../pref.cpp" line="233"/>
+        <location filename="../../pref.cpp" line="178"/>
         <source>Application restart is needed for changes to take effect.</source>
         <translation>A változtatások érvényesítéséhez az alkalmazás újraindítása szükséges.</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="222"/>
+        <location filename="../../pref.cpp" line="235"/>
         <source>Select libarchive binary</source>
         <translation>libarchive bináris kiválasztása</translation>
     </message>
@@ -160,453 +163,487 @@ Figyelmeztetés: Az Arqiver nem fog működni,
         <translation>S&amp;zerkesztés</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="153"/>
+        <location filename="../../mainWin.ui" line="155"/>
         <source>&amp;View</source>
         <translation>&amp;Nézet</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="164"/>
+        <location filename="../../mainWin.ui" line="166"/>
         <source>&amp;Help</source>
         <translation>&amp;Súgó</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="200"/>
+        <location filename="../../mainWin.ui" line="204"/>
         <source>&amp;Open Archive</source>
         <translation>&amp;Archívum megnyitása</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="203"/>
+        <location filename="../../mainWin.ui" line="207"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="208"/>
+        <location filename="../../mainWin.ui" line="212"/>
         <source>&amp;New Archive</source>
         <translation>Ú&amp;j archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="211"/>
+        <location filename="../../mainWin.ui" line="215"/>
         <source>Ctrl+N</source>
         <translation>Ctrl+N</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="216"/>
+        <location filename="../../mainWin.ui" line="220"/>
         <source>&amp;Quit</source>
         <translation>&amp;Kilépés</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="219"/>
+        <location filename="../../mainWin.ui" line="223"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="224"/>
+        <location filename="../../mainWin.ui" line="228"/>
         <source>Add File(s)</source>
         <translation>Fájlok hozzáadása</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="229"/>
+        <location filename="../../mainWin.ui" line="233"/>
         <source>Remove File(s)</source>
         <translation>Fájlok eltávolítása</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="234"/>
+        <location filename="../../mainWin.ui" line="238"/>
         <source>Extract All</source>
         <translation>Összes kibontása</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="237"/>
+        <location filename="../../mainWin.ui" line="241"/>
         <source>Ctrl+E</source>
         <translation>Ctrl+E</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="242"/>
+        <location filename="../../mainWin.ui" line="246"/>
         <source>Add Directory</source>
         <translation>Könyvtár hozzáadása</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="247"/>
+        <location filename="../../mainWin.ui" line="251"/>
         <source>Extract Selection</source>
         <translation>Kijelöltek kibontása</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="252"/>
+        <location filename="../../mainWin.ui" line="256"/>
         <source>Set Password</source>
         <translation>Jelszó beállítása</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="257"/>
+        <location filename="../../mainWin.ui" line="261"/>
         <source>E&amp;xpand</source>
         <translation>&amp;Kinyitás</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="260"/>
+        <location filename="../../mainWin.ui" line="264"/>
         <source>Ctrl+Shift+Down</source>
         <translation>Ctrl+Shift+Le</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="265"/>
+        <location filename="../../mainWin.ui" line="269"/>
         <source>Collap&amp;se</source>
         <translation>&amp;Becsukás</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="268"/>
+        <location filename="../../mainWin.ui" line="272"/>
         <source>Ctrl+Shift+Up</source>
         <translation>Ctrl+Shift+Fel</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="273"/>
+        <location filename="../../mainWin.ui" line="277"/>
         <source>&amp;About</source>
         <translation>&amp;Névjegy</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="278"/>
+        <location filename="../../mainWin.ui" line="282"/>
         <source>&amp;Copy Current Path</source>
         <translation>&amp;Legutóbbi útvonal másolása</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="283"/>
+        <location filename="../../mainWin.ui" line="287"/>
         <source>&amp;Preferences</source>
         <translation>&amp;Beállítások</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="288"/>
+        <location filename="../../mainWin.ui" line="292"/>
         <source>Stop &amp;Process</source>
         <translation>&amp;Folyamat leállítása</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="291"/>
+        <location filename="../../mainWin.ui" line="295"/>
         <source>Ctrl+S</source>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="148"/>
+        <location filename="../../mainWin.ui" line="305"/>
+        <source>Update Archive</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="149"/>
         <source>Root</source>
         <translation>Root</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="212"/>
+        <location filename="../../mainWin.cpp" line="254"/>
         <source>Error</source>
         <translation>Hiba</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="277"/>
+        <location filename="../../mainWin.cpp" line="325"/>
         <source>File</source>
         <translation>Fájl</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="277"/>
+        <location filename="../../mainWin.cpp" line="325"/>
         <source>MimeType</source>
         <translation>Mime típus</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="277"/>
+        <location filename="../../mainWin.cpp" line="325"/>
         <source>Size</source>
         <translation>Méret</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="488"/>
-        <location filename="../../mainWin.cpp" line="759"/>
-        <location filename="../../mainWin.cpp" line="802"/>
+        <location filename="../../mainWin.cpp" line="554"/>
+        <location filename="../../mainWin.cpp" line="839"/>
+        <location filename="../../mainWin.cpp" line="882"/>
         <source>Opening Archive...</source>
         <translation>Archívum megnyitása...</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="695"/>
+        <location filename="../../mainWin.cpp" line="768"/>
         <source>Create Archive</source>
         <translation>Archívum létrehozása</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="721"/>
-        <location filename="../../mainWin.cpp" line="911"/>
-        <location filename="../../mainWin.cpp" line="1196"/>
+        <location filename="../../mainWin.cpp" line="465"/>
+        <location filename="../../mainWin.cpp" line="794"/>
+        <location filename="../../mainWin.cpp" line="996"/>
+        <location filename="../../mainWin.cpp" line="1307"/>
         <source>Question</source>
         <translation>Kérdés</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="722"/>
+        <location filename="../../mainWin.cpp" line="795"/>
         <source>The following archive already exists:</source>
         <translation>A következő archívum már létezik :</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="724"/>
+        <location filename="../../mainWin.cpp" line="797"/>
         <source>Do you want to replace it?
 </source>
         <translation>Cserélni szeretné?
 </translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="751"/>
+        <location filename="../../mainWin.cpp" line="831"/>
         <source>Open Archive</source>
         <translation>Archívum megnyitása</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="817"/>
-        <location filename="../../mainWin.cpp" line="824"/>
-        <location filename="../../mainWin.cpp" line="860"/>
+        <location filename="../../mainWin.cpp" line="897"/>
+        <location filename="../../mainWin.cpp" line="904"/>
+        <location filename="../../mainWin.cpp" line="945"/>
         <source>Add to Archive</source>
         <translation>Hozzáadás archívumhoz</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="855"/>
-        <location filename="../../mainWin.cpp" line="886"/>
-        <location filename="../../mainWin.cpp" line="1151"/>
-        <location filename="../../mainWin.cpp" line="1157"/>
+        <location filename="../../mainWin.cpp" line="940"/>
+        <location filename="../../mainWin.cpp" line="971"/>
+        <location filename="../../mainWin.cpp" line="1254"/>
+        <location filename="../../mainWin.cpp" line="1260"/>
         <source>Adding Items...</source>
         <translation>Elemek hozzáadása...</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="912"/>
+        <location filename="../../mainWin.cpp" line="997"/>
         <source>Do you want to remove the selected item(s)?
 </source>
         <translation>Törölni szeretné a kijelölt elemeket?
 </translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="929"/>
+        <location filename="../../mainWin.cpp" line="1016"/>
         <source>Removing Items...</source>
         <translation>Elemek törlése...</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1114"/>
-        <location filename="../../mainWin.cpp" line="1129"/>
-        <location filename="../../mainWin.cpp" line="1209"/>
-        <location filename="../../mainWin.cpp" line="1223"/>
+        <location filename="../../mainWin.cpp" line="1217"/>
+        <location filename="../../mainWin.cpp" line="1232"/>
+        <location filename="../../mainWin.cpp" line="1322"/>
+        <location filename="../../mainWin.cpp" line="1336"/>
         <source>Extracting...</source>
         <translation>Kibontás...</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="969"/>
+        <location filename="../../mainWin.cpp" line="1060"/>
         <source>Copy Archive Path</source>
         <translation>Archívum útvonalának másolása</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="562"/>
+        <location filename="../../mainWin.cpp" line="466"/>
+        <source>Some files have been modified.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="467"/>
+        <source>Do you want to ignore the changes?
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="628"/>
         <source>All Types</source>
         <translation>Összes típus</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="572"/>
-        <location filename="../../mainWin.cpp" line="596"/>
+        <location filename="../../mainWin.cpp" line="638"/>
+        <location filename="../../mainWin.cpp" line="662"/>
         <source>Uncompressed Archive</source>
         <translation>Tömörítetlen archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="573"/>
-        <location filename="../../mainWin.cpp" line="597"/>
+        <location filename="../../mainWin.cpp" line="639"/>
+        <location filename="../../mainWin.cpp" line="663"/>
         <source>GZip Compressed Archive</source>
         <translation>GZippel tömörített archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="575"/>
-        <location filename="../../mainWin.cpp" line="599"/>
+        <location filename="../../mainWin.cpp" line="640"/>
+        <location filename="../../mainWin.cpp" line="664"/>
+        <location filename="../../mainWin.cpp" line="665"/>
+        <source>BZip Compressed Archive</source>
+        <translation>BZip-vel tömörített archívum</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="641"/>
+        <location filename="../../mainWin.cpp" line="666"/>
         <source>BZip2 Compressed Archive</source>
         <translation>BZip2-vel tömörített archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="576"/>
-        <location filename="../../mainWin.cpp" line="605"/>
+        <location filename="../../mainWin.cpp" line="642"/>
+        <location filename="../../mainWin.cpp" line="674"/>
         <source>LMZA Compressed Archive</source>
         <translation>LMZA-val tömörített archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="577"/>
-        <location filename="../../mainWin.cpp" line="602"/>
+        <location filename="../../mainWin.cpp" line="643"/>
+        <location filename="../../mainWin.cpp" line="671"/>
         <source>XZ Compressed Archive</source>
         <translation>XZ-vel tömörített archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="578"/>
-        <location filename="../../mainWin.cpp" line="606"/>
+        <location filename="../../mainWin.cpp" line="644"/>
+        <location filename="../../mainWin.cpp" line="675"/>
         <source>Zstandard Compressed Archive</source>
         <translation>Zstandarddal tömörített archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="579"/>
-        <location filename="../../mainWin.cpp" line="608"/>
+        <location filename="../../mainWin.cpp" line="645"/>
+        <location filename="../../mainWin.cpp" line="677"/>
         <source>CPIO Archive</source>
         <translation>CPIO archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="581"/>
-        <location filename="../../mainWin.cpp" line="610"/>
+        <location filename="../../mainWin.cpp" line="647"/>
+        <location filename="../../mainWin.cpp" line="679"/>
         <source>AR Archive</source>
         <translation>AR archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="583"/>
-        <location filename="../../mainWin.cpp" line="612"/>
+        <location filename="../../mainWin.cpp" line="649"/>
+        <location filename="../../mainWin.cpp" line="681"/>
         <source>Zip Archive</source>
         <translation>Zip archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="584"/>
-        <location filename="../../mainWin.cpp" line="614"/>
+        <location filename="../../mainWin.cpp" line="650"/>
+        <location filename="../../mainWin.cpp" line="683"/>
         <source>Gzip Archive</source>
         <translation>Gzip archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="585"/>
-        <location filename="../../mainWin.cpp" line="613"/>
+        <location filename="../../mainWin.cpp" line="651"/>
+        <location filename="../../mainWin.cpp" line="682"/>
         <source>7-Zip Archive</source>
         <translation>7-Zip archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="600"/>
+        <location filename="../../mainWin.cpp" line="667"/>
+        <location filename="../../mainWin.cpp" line="668"/>
+        <source>READ-ONLY: BZip Archive</source>
+        <translation>CSAK OLVASHATÓ: BZip archívum</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="669"/>
         <source>READ-ONLY: BZip2 Archive</source>
         <translation>CSAK OLVASHATÓ: BZip2 archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="601"/>
+        <location filename="../../mainWin.cpp" line="670"/>
         <source>READ-ONLY: BZip2 Compressed PDF Document</source>
         <translation>CSAK OLVASHATÓ: BZip2-vel tömörített PDF dokumentum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="603"/>
+        <location filename="../../mainWin.cpp" line="672"/>
         <source>READ-ONLY: XZ archive</source>
         <translation>CSAK OLVASHATÓ: XZ archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="604"/>
+        <location filename="../../mainWin.cpp" line="673"/>
         <source>READ-ONLY: XZ Compressed PDF Document</source>
         <translation>CSAK OLVASHATÓ: XZ-vel tömörített PDF dokumentum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="607"/>
+        <location filename="../../mainWin.cpp" line="676"/>
         <source>READ-ONLY: Zstandard archive</source>
         <translation>CSAK OLVASHATÓ: Zstandard archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="615"/>
+        <location filename="../../mainWin.cpp" line="684"/>
         <source>Gzip Compressed PDF Document</source>
         <translation>GZippel tömörített PDF dokumentum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="616"/>
+        <location filename="../../mainWin.cpp" line="685"/>
         <source>READ-ONLY: Compressed SVG Image</source>
         <translation>CSAK OLVASHATÓ: tömörített SVG kép</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="617"/>
-        <location filename="../../mainWin.cpp" line="618"/>
+        <location filename="../../mainWin.cpp" line="686"/>
+        <location filename="../../mainWin.cpp" line="687"/>
+        <location filename="../../mainWin.cpp" line="688"/>
+        <location filename="../../mainWin.cpp" line="689"/>
         <source>READ-ONLY: ISO Image</source>
         <translation>CSAK OLVASHATÓ: ISO kép</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="619"/>
+        <location filename="../../mainWin.cpp" line="690"/>
         <source>READ-ONLY: XAR Archive</source>
         <translation>CSAK OLVASHATÓ: XAR archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="620"/>
+        <location filename="../../mainWin.cpp" line="691"/>
         <source>READ-ONLY: Java Archive</source>
         <translation>CSAK OLVASHATÓ: Java archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="621"/>
+        <location filename="../../mainWin.cpp" line="692"/>
         <source>READ-ONLY: Debian Package</source>
         <translation>CSAK OLVASHATÓ: Debian csomag</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="622"/>
-        <location filename="../../mainWin.cpp" line="623"/>
+        <location filename="../../mainWin.cpp" line="693"/>
+        <location filename="../../mainWin.cpp" line="694"/>
         <source>READ-ONLY: RedHat Package</source>
         <translation>CSAK OLVASHATÓ: RedHat csomag</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="624"/>
+        <location filename="../../mainWin.cpp" line="695"/>
+        <location filename="../../mainWin.cpp" line="696"/>
+        <location filename="../../mainWin.cpp" line="697"/>
         <source>READ-ONLY: MS Windows Executable</source>
         <translation>CSAK OLVASHATÓ: MS Windows futtatható állomány</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="625"/>
+        <location filename="../../mainWin.cpp" line="698"/>
         <source>READ-ONLY: MS Windows Installer Package</source>
         <translation>CSAK OLVASHATÓ: MS Windows telepítőcsomag</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="626"/>
+        <location filename="../../mainWin.cpp" line="699"/>
         <source>READ-ONLY: MS Windows Cabinet Archive</source>
         <translation>CSAK OLVASHATÓ: MS Windows Cabinet archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="627"/>
+        <location filename="../../mainWin.cpp" line="700"/>
         <source>READ-ONLY: ACE archive</source>
         <translation>CSAK OLVASHATÓ: ACE archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="628"/>
+        <location filename="../../mainWin.cpp" line="701"/>
         <source>READ-ONLY: Android Package</source>
         <translation>CSAK OLVASHATÓ: Android csomag</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="629"/>
+        <location filename="../../mainWin.cpp" line="702"/>
         <source>READ-ONLY: RAR Archive</source>
         <translation>CSAK OLVASHATÓ: RAR archívum</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="630"/>
+        <location filename="../../mainWin.cpp" line="703"/>
         <source>READ-ONLY: AppImage application bundle</source>
         <translation>CSAK OLVASHATÓ: AppImage alkalmazáscsomag</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="631"/>
+        <location filename="../../mainWin.cpp" line="704"/>
         <source>READ-ONLY: VirtualBox Extension Pack</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="640"/>
+        <location filename="../../mainWin.cpp" line="713"/>
         <source>All Known Types</source>
         <translation>Összes ismert típus</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="645"/>
+        <location filename="../../mainWin.cpp" line="718"/>
         <source>Show All Files</source>
         <translation>Összes fájl megjelenítése</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="975"/>
+        <location filename="../../mainWin.cpp" line="1070"/>
         <source>Open Containing Folder</source>
         <translation>Tartalmazó mappa megnyitása</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="296"/>
+        <location filename="../../mainWin.ui" line="300"/>
         <source>View Current Item</source>
         <translation>Jelenlegi elem megtekintése</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1018"/>
-        <location filename="../../mainWin.cpp" line="1026"/>
+        <location filename="../../mainWin.cpp" line="1113"/>
+        <location filename="../../mainWin.cpp" line="1121"/>
         <source>Enter Password</source>
         <translation>Adja meg a jelszót</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1030"/>
+        <location filename="../../mainWin.cpp" line="1129"/>
         <source>Cancel</source>
         <translation>Mégse</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1031"/>
+        <location filename="../../mainWin.cpp" line="1134"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1035"/>
+        <location filename="../../mainWin.cpp" line="1138"/>
         <source>Encrypt the file list</source>
         <translation>Fájllista titkosítása</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1036"/>
+        <location filename="../../mainWin.cpp" line="1139"/>
         <source>This will take effect after files/folders are added.</source>
         <translation>Ez a fájlok/mappák hozzáadása után lép érvénybe.</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1107"/>
-        <location filename="../../mainWin.cpp" line="1183"/>
+        <location filename="../../mainWin.cpp" line="1210"/>
+        <location filename="../../mainWin.cpp" line="1286"/>
         <source>Extract Into Directory</source>
         <translation>Kibontás könyvtárba</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1197"/>
+        <location filename="../../mainWin.cpp" line="1308"/>
         <source>Some files will be overwritten.
 Do you want to continue?
 </source>
@@ -615,38 +652,43 @@ Folytatja?
 </translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1324"/>
+        <location filename="../../mainWin.cpp" line="1442"/>
         <source>Link To: %1</source>
         <translation>Link ide: %1</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1672"/>
+        <location filename="../../mainWin.cpp" line="1716"/>
+        <source>Could not read archive</source>
+        <translation>Nem sikerült olvasni az archívumot</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="1789"/>
         <source>A simple Qt archive manager</source>
         <translation>Egy egyszerű Qt archívumkezelő</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1673"/>
+        <location filename="../../mainWin.cpp" line="1790"/>
         <source>based on libarchive, gzip and 7z</source>
         <translation>amely a libarchive-on a gzipen és a 7z-n alapul</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1674"/>
+        <location filename="../../mainWin.cpp" line="1791"/>
         <source>Author</source>
         <translation>Szerző</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1675"/>
+        <location filename="../../mainWin.cpp" line="1792"/>
         <source>aka.</source>
         <translation>más néven</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1676"/>
-        <location filename="../../mainWin.cpp" line="1677"/>
+        <location filename="../../mainWin.cpp" line="1793"/>
+        <location filename="../../mainWin.cpp" line="1794"/>
         <source>About Arqiver</source>
         <translation>Arqiver névjegye</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1676"/>
+        <location filename="../../mainWin.cpp" line="1793"/>
         <source>Translators</source>
         <translation>Fordítók</translation>
     </message>
