@@ -4,7 +4,7 @@
 <context>
     <name>Arqiver::AboutDialog</name>
     <message>
-        <location filename="../../about.ui" line="144"/>
+        <location filename="../../about.ui" line="148"/>
         <source>License</source>
         <translation>Licenza</translation>
     </message>
@@ -12,44 +12,43 @@
 <context>
     <name>Arqiver::Backend</name>
     <message>
-        <location filename="../../backends.cpp" line="634"/>
-        <location filename="../../backends.cpp" line="667"/>
+        <location filename="../../backends.cpp" line="849"/>
         <source>This file is a link but its target does not exist.</source>
         <translation>Questo file è un collegamento a un altro file inesistente.</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1049"/>
-        <location filename="../../backends.cpp" line="1080"/>
-        <location filename="../../backends.cpp" line="1123"/>
+        <location filename="../../backends.cpp" line="1273"/>
+        <location filename="../../backends.cpp" line="1305"/>
+        <location filename="../../backends.cpp" line="1349"/>
         <source>Could not read archive</source>
         <translation>Impossibile leggere l&apos;archivio</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1083"/>
-        <location filename="../../backends.cpp" line="1128"/>
+        <location filename="../../backends.cpp" line="1308"/>
+        <location filename="../../backends.cpp" line="1354"/>
         <source>Archive Loaded</source>
         <translation>Archivio Caricato</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1090"/>
-        <location filename="../../backends.cpp" line="1176"/>
+        <location filename="../../backends.cpp" line="1315"/>
+        <location filename="../../backends.cpp" line="1402"/>
         <source>Modification Finished</source>
         <translation>Modifica Terminata</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1111"/>
-        <location filename="../../backends.cpp" line="1145"/>
+        <location filename="../../backends.cpp" line="1336"/>
+        <location filename="../../backends.cpp" line="1371"/>
         <source>Extraction Finished</source>
         <translation>Estrazione Terminata</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1114"/>
-        <location filename="../../backends.cpp" line="1164"/>
+        <location filename="../../backends.cpp" line="1339"/>
+        <location filename="../../backends.cpp" line="1390"/>
         <source>Extraction Failed</source>
         <translation>Estrazione Non Riuscita</translation>
     </message>
     <message>
-        <location filename="../../backends.cpp" line="1273"/>
+        <location filename="../../backends.cpp" line="1487"/>
         <source>%1 is missing from your system.
 Please install it for this kind of archive!</source>
         <translation>%1 non è presente nel tuo sistema.
@@ -80,22 +79,27 @@ Cancella il testo con il tasto Esc.</translation>
     </message>
     <message>
         <location filename="../../pref.ui" line="118"/>
+        <source>Use system icons where possible</source>
+        <translation>Usa icone del sistema dov&apos;è possible</translation>
+    </message>
+    <message>
+        <location filename="../../pref.ui" line="125"/>
         <source>Show prompt on removing items</source>
         <translation>Mostra prompt alla rimozione di elementi</translation>
     </message>
     <message>
-        <location filename="../../pref.ui" line="125"/>
+        <location filename="../../pref.ui" line="132"/>
         <source>If this is unchecked, only the top level directories will be expanded.</source>
         <translation>Se questa opzione è deselezionata, verranno espanse solo le directory di livello superiore.</translation>
     </message>
     <message>
-        <location filename="../../pref.ui" line="128"/>
+        <location filename="../../pref.ui" line="135"/>
         <source>Expand all directories when opening archives</source>
         <translation>Espandi tutte le directory all&apos;apertura degli archivi</translation>
     </message>
     <message>
-        <location filename="../../pref.ui" line="140"/>
-        <location filename="../../pref.ui" line="153"/>
+        <location filename="../../pref.ui" line="147"/>
+        <location filename="../../pref.ui" line="160"/>
         <source>Leave empty for the default.
 
 Warning: Arqiver will not work if the
@@ -106,7 +110,7 @@ Avvertenza: Arqiver non funzionerà se
 l&apos;eseguibile non è incluso in libarchive.</translation>
     </message>
     <message>
-        <location filename="../../pref.ui" line="146"/>
+        <location filename="../../pref.ui" line="153"/>
         <source>libarchive binary:</source>
         <translation>Eseguibile di libarchive:</translation>
     </message>
@@ -121,18 +125,17 @@ l&apos;eseguibile non è incluso in libarchive.</translation>
         <translation>Dimensione delle icone della vista:</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="54"/>
+        <location filename="../../pref.cpp" line="56"/>
         <source>px</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="208"/>
-        <location filename="../../pref.cpp" line="233"/>
+        <location filename="../../pref.cpp" line="178"/>
         <source>Application restart is needed for changes to take effect.</source>
         <translation>Per rendere effettive le modifiche è necessario riavviare l&apos;applicazione.</translation>
     </message>
     <message>
-        <location filename="../../pref.cpp" line="222"/>
+        <location filename="../../pref.cpp" line="235"/>
         <source>Select libarchive binary</source>
         <translation>Seleziona l&apos;eseguibile di libarchive</translation>
     </message>
@@ -160,453 +163,488 @@ l&apos;eseguibile non è incluso in libarchive.</translation>
         <translation>&amp;Modifica</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="153"/>
+        <location filename="../../mainWin.ui" line="155"/>
         <source>&amp;View</source>
         <translation>&amp;Visualizza</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="164"/>
+        <location filename="../../mainWin.ui" line="166"/>
         <source>&amp;Help</source>
         <translation>&amp;Aiuto</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="200"/>
+        <location filename="../../mainWin.ui" line="204"/>
         <source>&amp;Open Archive</source>
         <translation>&amp;Apri Archivio</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="203"/>
+        <location filename="../../mainWin.ui" line="207"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="208"/>
+        <location filename="../../mainWin.ui" line="212"/>
         <source>&amp;New Archive</source>
         <translation>&amp;Nuovo Archivio</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="211"/>
+        <location filename="../../mainWin.ui" line="215"/>
         <source>Ctrl+N</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="216"/>
+        <location filename="../../mainWin.ui" line="220"/>
         <source>&amp;Quit</source>
         <translation>&amp;Esci</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="219"/>
+        <location filename="../../mainWin.ui" line="223"/>
         <source>Ctrl+Q</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="224"/>
+        <location filename="../../mainWin.ui" line="228"/>
         <source>Add File(s)</source>
         <translation>Aggiungi File</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="229"/>
+        <location filename="../../mainWin.ui" line="233"/>
         <source>Remove File(s)</source>
         <translation>Rimuovi File</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="234"/>
+        <location filename="../../mainWin.ui" line="238"/>
         <source>Extract All</source>
         <translation>Estrai Tutto</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="237"/>
+        <location filename="../../mainWin.ui" line="241"/>
         <source>Ctrl+E</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="242"/>
+        <location filename="../../mainWin.ui" line="246"/>
         <source>Add Directory</source>
         <translation>Aggiungi Directory</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="247"/>
+        <location filename="../../mainWin.ui" line="251"/>
         <source>Extract Selection</source>
         <translation>Estrai Selezione</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="252"/>
+        <location filename="../../mainWin.ui" line="256"/>
         <source>Set Password</source>
         <translation>Imposta Password</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="257"/>
+        <location filename="../../mainWin.ui" line="261"/>
         <source>E&amp;xpand</source>
         <translation>&amp;Espandi</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="260"/>
+        <location filename="../../mainWin.ui" line="264"/>
         <source>Ctrl+Shift+Down</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="265"/>
+        <location filename="../../mainWin.ui" line="269"/>
         <source>Collap&amp;se</source>
         <translation>&amp;Contrai</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="268"/>
+        <location filename="../../mainWin.ui" line="272"/>
         <source>Ctrl+Shift+Up</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="273"/>
+        <location filename="../../mainWin.ui" line="277"/>
         <source>&amp;About</source>
         <translation>&amp;Informazioni</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="278"/>
+        <location filename="../../mainWin.ui" line="282"/>
         <source>&amp;Copy Current Path</source>
         <translation>&amp;Copia Percorso Corrente</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="283"/>
+        <location filename="../../mainWin.ui" line="287"/>
         <source>&amp;Preferences</source>
         <translation>&amp;Preferenze</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="288"/>
+        <location filename="../../mainWin.ui" line="292"/>
         <source>Stop &amp;Process</source>
         <translation>Termina &amp;Processo</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="291"/>
+        <location filename="../../mainWin.ui" line="295"/>
         <source>Ctrl+S</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="148"/>
+        <location filename="../../mainWin.ui" line="305"/>
+        <source>Update Archive</source>
+        <translation>Aggiorna archivio</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="149"/>
         <source>Root</source>
         <translation>Radice</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="212"/>
+        <location filename="../../mainWin.cpp" line="254"/>
         <source>Error</source>
         <translation>Errore</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="277"/>
+        <location filename="../../mainWin.cpp" line="325"/>
         <source>File</source>
         <translation>File</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="277"/>
+        <location filename="../../mainWin.cpp" line="325"/>
         <source>MimeType</source>
         <translation>Tipo MIME</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="277"/>
+        <location filename="../../mainWin.cpp" line="325"/>
         <source>Size</source>
         <translation>Dimensione</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="488"/>
-        <location filename="../../mainWin.cpp" line="759"/>
-        <location filename="../../mainWin.cpp" line="802"/>
+        <location filename="../../mainWin.cpp" line="554"/>
+        <location filename="../../mainWin.cpp" line="839"/>
+        <location filename="../../mainWin.cpp" line="882"/>
         <source>Opening Archive...</source>
         <translation>Apertura Archivio...</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="695"/>
+        <location filename="../../mainWin.cpp" line="768"/>
         <source>Create Archive</source>
         <translation>Crea Archivio</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="721"/>
-        <location filename="../../mainWin.cpp" line="911"/>
-        <location filename="../../mainWin.cpp" line="1196"/>
+        <location filename="../../mainWin.cpp" line="465"/>
+        <location filename="../../mainWin.cpp" line="794"/>
+        <location filename="../../mainWin.cpp" line="996"/>
+        <location filename="../../mainWin.cpp" line="1307"/>
         <source>Question</source>
         <translation>Richiesta</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="722"/>
+        <location filename="../../mainWin.cpp" line="795"/>
         <source>The following archive already exists:</source>
         <translation>Il seguente archivio esiste già:</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="724"/>
+        <location filename="../../mainWin.cpp" line="797"/>
         <source>Do you want to replace it?
 </source>
         <translation>Vuoi sostituirlo?
 </translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="751"/>
+        <location filename="../../mainWin.cpp" line="831"/>
         <source>Open Archive</source>
         <translation>Apri Archivio</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="817"/>
-        <location filename="../../mainWin.cpp" line="824"/>
-        <location filename="../../mainWin.cpp" line="860"/>
+        <location filename="../../mainWin.cpp" line="897"/>
+        <location filename="../../mainWin.cpp" line="904"/>
+        <location filename="../../mainWin.cpp" line="945"/>
         <source>Add to Archive</source>
         <translation>Aggiungi ad Archivio</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="855"/>
-        <location filename="../../mainWin.cpp" line="886"/>
-        <location filename="../../mainWin.cpp" line="1151"/>
-        <location filename="../../mainWin.cpp" line="1157"/>
+        <location filename="../../mainWin.cpp" line="940"/>
+        <location filename="../../mainWin.cpp" line="971"/>
+        <location filename="../../mainWin.cpp" line="1254"/>
+        <location filename="../../mainWin.cpp" line="1260"/>
         <source>Adding Items...</source>
         <translation>Aggiungo elementi...</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="912"/>
+        <location filename="../../mainWin.cpp" line="997"/>
         <source>Do you want to remove the selected item(s)?
 </source>
         <translation>Vuoi rimuovere gli elementi selezionati?
 </translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="929"/>
+        <location filename="../../mainWin.cpp" line="1016"/>
         <source>Removing Items...</source>
         <translation>Rimuovo Elementi...</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1114"/>
-        <location filename="../../mainWin.cpp" line="1129"/>
-        <location filename="../../mainWin.cpp" line="1209"/>
-        <location filename="../../mainWin.cpp" line="1223"/>
+        <location filename="../../mainWin.cpp" line="1217"/>
+        <location filename="../../mainWin.cpp" line="1232"/>
+        <location filename="../../mainWin.cpp" line="1322"/>
+        <location filename="../../mainWin.cpp" line="1336"/>
         <source>Extracting...</source>
         <translation>Estrazione...</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="969"/>
+        <location filename="../../mainWin.cpp" line="1060"/>
         <source>Copy Archive Path</source>
         <translation>Copia Percorso Archivio</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="562"/>
+        <location filename="../../mainWin.cpp" line="466"/>
+        <source>Some files have been modified.</source>
+        <translation>Alcuni file sono stati modificati.</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="467"/>
+        <source>Do you want to ignore the changes?
+</source>
+        <translation>Ignorare i cambiamenti?
+</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="628"/>
         <source>All Types</source>
         <translation>Tutti I Tipi</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="572"/>
-        <location filename="../../mainWin.cpp" line="596"/>
+        <location filename="../../mainWin.cpp" line="638"/>
+        <location filename="../../mainWin.cpp" line="662"/>
         <source>Uncompressed Archive</source>
         <translation>Archivio Non Compresso</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="573"/>
-        <location filename="../../mainWin.cpp" line="597"/>
+        <location filename="../../mainWin.cpp" line="639"/>
+        <location filename="../../mainWin.cpp" line="663"/>
         <source>GZip Compressed Archive</source>
         <translation>Archivio Compresso GZip</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="575"/>
-        <location filename="../../mainWin.cpp" line="599"/>
+        <location filename="../../mainWin.cpp" line="640"/>
+        <location filename="../../mainWin.cpp" line="664"/>
+        <location filename="../../mainWin.cpp" line="665"/>
+        <source>BZip Compressed Archive</source>
+        <translation>Archivio Compresso BZip</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="641"/>
+        <location filename="../../mainWin.cpp" line="666"/>
         <source>BZip2 Compressed Archive</source>
         <translation>Archivio Compresso BZip2</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="576"/>
-        <location filename="../../mainWin.cpp" line="605"/>
+        <location filename="../../mainWin.cpp" line="642"/>
+        <location filename="../../mainWin.cpp" line="674"/>
         <source>LMZA Compressed Archive</source>
         <translation>Archivio Compresso LZMA</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="577"/>
-        <location filename="../../mainWin.cpp" line="602"/>
+        <location filename="../../mainWin.cpp" line="643"/>
+        <location filename="../../mainWin.cpp" line="671"/>
         <source>XZ Compressed Archive</source>
         <translation>Archivio Compresso XZ</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="578"/>
-        <location filename="../../mainWin.cpp" line="606"/>
+        <location filename="../../mainWin.cpp" line="644"/>
+        <location filename="../../mainWin.cpp" line="675"/>
         <source>Zstandard Compressed Archive</source>
         <translation>Archivio Compresso Zstandard</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="579"/>
-        <location filename="../../mainWin.cpp" line="608"/>
+        <location filename="../../mainWin.cpp" line="645"/>
+        <location filename="../../mainWin.cpp" line="677"/>
         <source>CPIO Archive</source>
         <translation>Archivio CPIO</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="581"/>
-        <location filename="../../mainWin.cpp" line="610"/>
+        <location filename="../../mainWin.cpp" line="647"/>
+        <location filename="../../mainWin.cpp" line="679"/>
         <source>AR Archive</source>
         <translation>Archivio AR</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="583"/>
-        <location filename="../../mainWin.cpp" line="612"/>
+        <location filename="../../mainWin.cpp" line="649"/>
+        <location filename="../../mainWin.cpp" line="681"/>
         <source>Zip Archive</source>
         <translation>Archivio Zip</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="584"/>
-        <location filename="../../mainWin.cpp" line="614"/>
+        <location filename="../../mainWin.cpp" line="650"/>
+        <location filename="../../mainWin.cpp" line="683"/>
         <source>Gzip Archive</source>
         <translation>Archivio Gzip</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="585"/>
-        <location filename="../../mainWin.cpp" line="613"/>
+        <location filename="../../mainWin.cpp" line="651"/>
+        <location filename="../../mainWin.cpp" line="682"/>
         <source>7-Zip Archive</source>
         <translation>Archivio 7-Zip</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="600"/>
+        <location filename="../../mainWin.cpp" line="667"/>
+        <location filename="../../mainWin.cpp" line="668"/>
+        <source>READ-ONLY: BZip Archive</source>
+        <translation>SOLA-LETTURA: Archivio BZip</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="669"/>
         <source>READ-ONLY: BZip2 Archive</source>
         <translation>SOLA-LETTURA: Archivio BZip2</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="601"/>
+        <location filename="../../mainWin.cpp" line="670"/>
         <source>READ-ONLY: BZip2 Compressed PDF Document</source>
         <translation>SOLA-LETTURA: Documento PDF Compresso BZip2</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="603"/>
+        <location filename="../../mainWin.cpp" line="672"/>
         <source>READ-ONLY: XZ archive</source>
         <translation>SOLA-LETTURA: Archivio XZ</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="604"/>
+        <location filename="../../mainWin.cpp" line="673"/>
         <source>READ-ONLY: XZ Compressed PDF Document</source>
         <translation>SOLA-LETTURA: Documento PDF Compresso XZ</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="607"/>
+        <location filename="../../mainWin.cpp" line="676"/>
         <source>READ-ONLY: Zstandard archive</source>
         <translation>SOLA-LETTURA: Archivio Zstandard</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="615"/>
+        <location filename="../../mainWin.cpp" line="684"/>
         <source>Gzip Compressed PDF Document</source>
         <translation>Documento PDF Compresso Gzip</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="616"/>
+        <location filename="../../mainWin.cpp" line="685"/>
         <source>READ-ONLY: Compressed SVG Image</source>
         <translation>SOLA-LETTURA: Immagine SVG Compressa</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="617"/>
-        <location filename="../../mainWin.cpp" line="618"/>
+        <location filename="../../mainWin.cpp" line="686"/>
+        <location filename="../../mainWin.cpp" line="687"/>
+        <location filename="../../mainWin.cpp" line="688"/>
+        <location filename="../../mainWin.cpp" line="689"/>
         <source>READ-ONLY: ISO Image</source>
         <translation>SOLA-LETTURA: Immagine ISO</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="619"/>
+        <location filename="../../mainWin.cpp" line="690"/>
         <source>READ-ONLY: XAR Archive</source>
         <translation>SOLA-LETTURA: Archivio XAR</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="620"/>
+        <location filename="../../mainWin.cpp" line="691"/>
         <source>READ-ONLY: Java Archive</source>
         <translation>SOLA-LETTURA: Archivio Java</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="621"/>
+        <location filename="../../mainWin.cpp" line="692"/>
         <source>READ-ONLY: Debian Package</source>
         <translation>SOLA-LETTURA: Pacchetto Debian</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="622"/>
-        <location filename="../../mainWin.cpp" line="623"/>
+        <location filename="../../mainWin.cpp" line="693"/>
+        <location filename="../../mainWin.cpp" line="694"/>
         <source>READ-ONLY: RedHat Package</source>
         <translation>SOLA-LETTURA: Pacchetto RedHat</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="624"/>
+        <location filename="../../mainWin.cpp" line="695"/>
+        <location filename="../../mainWin.cpp" line="696"/>
+        <location filename="../../mainWin.cpp" line="697"/>
         <source>READ-ONLY: MS Windows Executable</source>
         <translation>SOLA-LETTURA: Eseguibile MS Windows</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="625"/>
+        <location filename="../../mainWin.cpp" line="698"/>
         <source>READ-ONLY: MS Windows Installer Package</source>
         <translation>SOLA-LETTURA: Pacchetto Installazione MS Windows</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="626"/>
+        <location filename="../../mainWin.cpp" line="699"/>
         <source>READ-ONLY: MS Windows Cabinet Archive</source>
         <translation>SOLA-LETTURA: Archivio Cabinet MS Windows</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="627"/>
+        <location filename="../../mainWin.cpp" line="700"/>
         <source>READ-ONLY: ACE archive</source>
         <translation>SOLA-LETTURA: Archivio ACE</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="628"/>
+        <location filename="../../mainWin.cpp" line="701"/>
         <source>READ-ONLY: Android Package</source>
         <translation>SOLA-LETTURA: Pacchetto Android</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="629"/>
+        <location filename="../../mainWin.cpp" line="702"/>
         <source>READ-ONLY: RAR Archive</source>
         <translation>SOLA-LETTURA: Archivio RAR</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="630"/>
+        <location filename="../../mainWin.cpp" line="703"/>
         <source>READ-ONLY: AppImage application bundle</source>
         <translation>SOLO IN LETTURA: Bundle Appimage</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="631"/>
+        <location filename="../../mainWin.cpp" line="704"/>
         <source>READ-ONLY: VirtualBox Extension Pack</source>
         <translation>SOLA LETTURA: Pacchetto di estensioni VirtualBox</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="640"/>
+        <location filename="../../mainWin.cpp" line="713"/>
         <source>All Known Types</source>
         <translation>Tutti I Tipi</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="645"/>
+        <location filename="../../mainWin.cpp" line="718"/>
         <source>Show All Files</source>
         <translation>Mostra Tutti I File</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="975"/>
+        <location filename="../../mainWin.cpp" line="1070"/>
         <source>Open Containing Folder</source>
         <translation>Apri Cartella Contentente</translation>
     </message>
     <message>
-        <location filename="../../mainWin.ui" line="296"/>
+        <location filename="../../mainWin.ui" line="300"/>
         <source>View Current Item</source>
         <translation>Mostra Elemento Corrente</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1018"/>
-        <location filename="../../mainWin.cpp" line="1026"/>
+        <location filename="../../mainWin.cpp" line="1113"/>
+        <location filename="../../mainWin.cpp" line="1121"/>
         <source>Enter Password</source>
         <translation>Inserisci Password</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1030"/>
+        <location filename="../../mainWin.cpp" line="1129"/>
         <source>Cancel</source>
         <translation>Annulla</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1031"/>
+        <location filename="../../mainWin.cpp" line="1134"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1035"/>
+        <location filename="../../mainWin.cpp" line="1138"/>
         <source>Encrypt the file list</source>
         <translation>Cripta l&apos;elenco dei file</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1036"/>
+        <location filename="../../mainWin.cpp" line="1139"/>
         <source>This will take effect after files/folders are added.</source>
         <translation>Ciò avrà effetto dopo l&apos;aggiunta dei file/cartelle.</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1107"/>
-        <location filename="../../mainWin.cpp" line="1183"/>
+        <location filename="../../mainWin.cpp" line="1210"/>
+        <location filename="../../mainWin.cpp" line="1286"/>
         <source>Extract Into Directory</source>
         <translation>Estrai Nella Directory</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1197"/>
+        <location filename="../../mainWin.cpp" line="1308"/>
         <source>Some files will be overwritten.
 Do you want to continue?
 </source>
@@ -615,38 +653,43 @@ Vuoi continuare?
 </translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1324"/>
+        <location filename="../../mainWin.cpp" line="1442"/>
         <source>Link To: %1</source>
         <translation>Collegamento A: %1</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1672"/>
+        <location filename="../../mainWin.cpp" line="1716"/>
+        <source>Could not read archive</source>
+        <translation>Impossibile leggere l&apos;archivio</translation>
+    </message>
+    <message>
+        <location filename="../../mainWin.cpp" line="1789"/>
         <source>A simple Qt archive manager</source>
         <translation>Un semplice gestore di archivi in Qt</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1673"/>
+        <location filename="../../mainWin.cpp" line="1790"/>
         <source>based on libarchive, gzip and 7z</source>
         <translation>basato su libarchive, gzip e 7z</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1674"/>
+        <location filename="../../mainWin.cpp" line="1791"/>
         <source>Author</source>
         <translation>Autore</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1675"/>
+        <location filename="../../mainWin.cpp" line="1792"/>
         <source>aka.</source>
         <translation>alias</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1676"/>
-        <location filename="../../mainWin.cpp" line="1677"/>
+        <location filename="../../mainWin.cpp" line="1793"/>
+        <location filename="../../mainWin.cpp" line="1794"/>
         <source>About Arqiver</source>
         <translation>Informazioni su Arqiver</translation>
     </message>
     <message>
-        <location filename="../../mainWin.cpp" line="1676"/>
+        <location filename="../../mainWin.cpp" line="1793"/>
         <source>Translators</source>
         <translation>Traduttori</translation>
     </message>
